Crate splinter[−][src]
Re-exports
pub use actix_web; | |
pub use futures; |
Modules
| admin | |
| biome | The Biome submodule provides support for user management, user credential management, private key management, and user notifications. |
| channel | |
| circuit | |
| consensus | The API that defines interactions between consensus and a Splinter service. |
| error | Common set of basic errors used throughout the library. |
| events | |
| keys | Role-based permissions for public keys. |
| mesh | Mesh is an asynchronous Connection handler that sends and receives across many Connections in a background thread. |
| metrics | |
| migrations | Provides sql migration scripts and methods for executing migrations. |
| network | |
| oauth | Support for OAuth2 authorization in Splinter |
| orchestrator | |
| peer | Data structures and implementations for managing Splinter peers. |
| protocol | Protocol versions for various endpoints provided by splinter. |
| protos | |
| registry | Data structures, traits, and implementations for tracking and managing known Splinter entities. |
| rest_api | Rest API Module. |
| service | Splinter services are a fundamental component of a Splinter network. They provide the application-level business logic, abstracted above the underlying network and circuit layers. The Service API provides a framework for defining services from a Splinter perspective. |
| sets | Durable sets, both ordered and unordered. Implementations of these sets must be thread-safe. |
| store | Contains a |
| threading | This module will contain components that will be used to support different threading models |
| transport | Traits and implementations for low-level message-based network communication. |
Macros
| mutex_lock_unwrap | |
| rwlock_read_unwrap | |
| rwlock_write_unwrap |