pub struct DieselAdminServiceStore<C: Connection + 'static> { /* private fields */ }
A database-backed AdminServiceStore, powered by Diesel.

Implementations

Creates a new DieselAdminServiceStore.

Arguments
  • connection_pool: connection pool for the database

Create a new DieselAdminServiceStore with write exclusivity enabled.

Write exclusivity is enforced by providing a connection pool that is wrapped in a RwLock. This ensures that there may be only one writer, but many readers.

Arguments
  • connection_pool: read-write lock-guarded connection pool for the database