pub struct CredentialsBuilder { /* private fields */ }
Builder for Credential. It hashes the password upon build.

Implementations

Sets the user_id for the user the credentials belong to

Arguments
  • user_id: unique identifier for the user the credentials belong to

Sets the username for the credentials

Arguments
  • username: username that will be used to authenticate the user

Sets the password for the credentials

Arguments
  • password: password that will be used to authenticate the user

Sets the cost to encrypt the password for the credentials

Arguments
  • cost: cost of the password encryption, default is high

Consumes the builder, hashes the password and returns Credentials with the hashed password