pub struct DieselOAuthUserSessionStore<C: Connection + 'static> { /* private fields */ }
A database-backed OAuthUserSessionStore, powered by diesel.

Implementations

Create a new DieselOAuthUserSessionStore with write exclusivity enabled.

Write exclusivity is enforced by providing a connection pool that is wrapped in a RwLock. This ensures that there may be only one writer, but many readers.

Arguments
  • connection_pool: read-write lock-guarded connection pool for the database