pub struct Mesh { /* private fields */ }Expand description
A Connection reactor
Implementations
sourceimpl Mesh
impl Mesh
sourcepub fn new(incoming_capacity: usize, outgoing_capacity: usize) -> Self
pub fn new(incoming_capacity: usize, outgoing_capacity: usize) -> Self
Create a new mesh, spawning a background thread for sending and receiving, and setting up channels to communicate with it.
sourcepub fn add(
&self,
connection: Box<dyn Connection>,
unique_id: String
) -> Result<usize, AddError>
pub fn add(
&self,
connection: Box<dyn Connection>,
unique_id: String
) -> Result<usize, AddError>
Add a new connection to the mesh, moving it to the background thread, and add the returned mesh id to the unique_ids map
sourcepub fn remove(&self, unique_id: &str) -> Result<Box<dyn Connection>, RemoveError>
pub fn remove(&self, unique_id: &str) -> Result<Box<dyn Connection>, RemoveError>
Remove an existing connection from the mesh and return it.
sourcepub fn send(&self, envelope: Envelope) -> Result<(), SendError>
pub fn send(&self, envelope: Envelope) -> Result<(), SendError>
Send the envelope on the mesh.
This is a convenience function and is equivalent to
mesh.outgoing(envelope.id()).send(Vec::from(envelope)).
sourcepub fn recv_timeout(
&self,
timeout: Duration
) -> Result<Envelope, RecvTimeoutError>
pub fn recv_timeout(
&self,
timeout: Duration
) -> Result<Envelope, RecvTimeoutError>
Receive a new envelope from the mesh.
sourcepub fn get_life_cycle(&self) -> MeshLifeCycle
pub fn get_life_cycle(&self) -> MeshLifeCycle
Creates a MeshLifeCycle that can be used to add and remove connection from this Mesh
sourcepub fn get_sender(&self) -> MeshMatrixSender
pub fn get_sender(&self) -> MeshMatrixSender
Creates a MeshMatrixSender that can be used to send messages over through this Mesh
sourcepub fn get_receiver(&self) -> MeshMatrixReceiver
pub fn get_receiver(&self) -> MeshMatrixReceiver
Creates a MeshMatrixReceiver that can be used to receives message from this Mesh