Struct splinter::oauth::GithubOAuthClientBuilder [−][src]
pub struct GithubOAuthClientBuilder { /* fields omitted */ }Expand description
Builds a new OAuthClient with GitHub’s authorization and token URLs.
Implementations
Sets the client ID for the OAuth2 provider.
Sets the client secret for the OAuth2 provider.
Sets the redirect URL for the OAuth2 provider.
pub fn with_inflight_request_store(
self,
inflight_request_store: Box<dyn InflightOAuthRequestStore>
) -> Self
pub fn with_inflight_request_store(
self,
inflight_request_store: Box<dyn InflightOAuthRequestStore>
) -> SelfSets the in-flight request store in order to store values between requests to and from the OAuth2 provider.
Builds an OAuthClient.
Errors
Returns an OAuthClientBuildError if there are required fields missing, or any URL’s
provided are invalid.