Trait splinter::oauth::ProfileProvider [−][src]
pub trait ProfileProvider: Send + Sync { fn get_profile(
&self,
access_token: &str
) -> Result<Option<Profile>, InternalError>; fn clone_box(&self) -> Box<dyn ProfileProvider>; }
A service that fetches profile details from a backing OAuth server
Required methods
fn get_profile(
&self,
access_token: &str
) -> Result<Option<Profile>, InternalError>
fn get_profile(
&self,
access_token: &str
) -> Result<Option<Profile>, InternalError>Attempts to get the profile details for the account that the given access token is for.
fn clone_box(&self) -> Box<dyn ProfileProvider>
fn clone_box(&self) -> Box<dyn ProfileProvider>Clone implementation for ProfileProvider. The implementation of the Clone trait for
Box<dyn ProfileProvider> calls this method.