Module splinter::orchestrator[][src]

Structs

JoinHandles
NewOrchestratorError
RunnableServiceOrchestrator

A runnable service orchestrator is configured, but not started ServiceOrchestrator. It may only be used for operations that can be done during that state, such as starting the orchestrator.

ServiceDefinition

Identifies a unique service instance from the perspective of the orchestrator

ServiceOrchestrator

The ServiceOrchestrator manages initialization and shutdown of services.

ServiceOrchestratorBuilder

Builds new RunnableServiceOrchestrator instances.

ServiceOrchestratorShutdownHandle

Enums

AddServiceError
InitializeServiceError
ListServicesError
OrchestratorError
ShutdownServiceError