Struct splinter::orchestrator::ServiceOrchestratorBuilder [−][src]
pub struct ServiceOrchestratorBuilder { /* fields omitted */ }Expand description
Builds new RunnableServiceOrchestrator instances.
Implementations
Sets the connection for receiving service messages by the resulting ServiceOrchestrator.
This field is required to construct the final ServiceOrchestrator.
Sets the incoming message capacity.
This limits the amount of messages that may be buffered by the service orchestrator before blocking new messages.
Sets the outgoing message capacity.
This limits the amount of messages that may be buffered by the service orchestrator when being sent to external connections.
Sets the internal channel capacity.
This limits the number of messages that may be buffered when passed between the internal threads.
Adds a service factory which will be used to create service instances.
This function may be called more than once to add additional service factories.
Construct the RunnableServiceOrchestrator.
Errors
Returns an InvalidStateError, if any required fields are missing.