[−][src]Struct splinter::protocol::service::ServiceDisconnectRequest
This message is sent by a service processor component to disconnect from a splinter node.
Fields
correlation_id: StringID used to correlate the response with this request