Module splinter::protos [−][src]
Modules
| admin | Generated file from |
| authorization | Generated file from |
| circuit | Generated file from |
| component | Generated file from |
| consensus | Generated file from |
| network | Generated file from |
| prelude | Allows for the convenient requirement of the proto conversion traits and errors. |
| service | Generated file from |
| two_phase | Generated file from |
Enums
| ProtoConversionError |
Traits
| FromBytes | Convert from bytes into a native struct, via the given protocol. |
| FromNative | |
| FromProto | |
| IntoBytes | Convert to bytes from a native struct, via the given protocol. |
| IntoNative | |
| IntoProto |