pub struct OAuthUserIdentityProvider { /* private fields */ }
An identity provider, backed by an OAuth server, that returns a user’s Biome ID

This provider uses an OAuthUserSessionStore as a cache of identities. The session store tracks all OAuth users’ sessions with a “last authenticated” timestamp. Sessions are initially added by the OAuth REST API endpoints when a user logs in.

If the session has not been authenticated within the re-authentication interval, the user will be re-authenticated using the internal OAuthClient and the session will be updated in the session store. If re-authentication fails, the session will be removed from the store and the user will need to start a new session by logging in.

This identity provider will also use a session’s refresh token (if it has one) to get a new OAuth access token for the session as needed.

This provider only accepts AuthorizationHeader::Bearer(BearerToken::OAuth2(token)) authorizations, and the inner token must be a valid Splinter access token for an OAuth user.

Implementations

Creates a new OAuth user identity provider

Arguments
  • oauth_client - The OAuth client that will be used to check if a session is still valid
  • oauth_user_session_store - The store that tracks users’ sessions
  • reauthentication_interval - The amount of time since the last authentication for which the identity provider can assume the session is still valid. If this amount of time has elapsed since the last authentication of a session, the session will be re-authenticated by the identity provider. If not provided, the default will be used (1 hour).