Struct splinter::sets::mem::DurableBTreeSet[][src]

pub struct DurableBTreeSet<V: Ord + Send> { /* fields omitted */ }
An in-memory, DurableOrderedSet, backed by a BTreeSet.

This set is bounded, where in it will drop the first item in the set, based on the natural order of the items stored.

Implementations