Struct splinter::sets::DurableRange[][src]

pub struct DurableRange<T> {
    pub start: Bound<T>,
    pub end: Bound<T>,
}
A Range describing the start and end bounds for a range iterator on a DurableOrderedSet.

This struct is similar to the various implementations of the RangeBounds trait in the standard library, but is necessary for implementing the most generic set of bounds while still allowing DurableOrderedSet to be used as in a boxed-dyn context.

Fields

start: Bound<T>end: Bound<T>