pub struct DieselAdminServiceStore<C: Connection + 'static> { /* private fields */ }Expand description
A database-backed AdminServiceStore, powered by Diesel.
Implementations
sourceimpl<C: Connection> DieselAdminServiceStore<C>
impl<C: Connection> DieselAdminServiceStore<C>
sourcepub fn new(connection_pool: Pool<ConnectionManager<C>>) -> Self
pub fn new(connection_pool: Pool<ConnectionManager<C>>) -> Self
sourcepub fn new_with_write_exclusivity(
connection_pool: Arc<RwLock<Pool<ConnectionManager<C>>>>
) -> Self
pub fn new_with_write_exclusivity(
connection_pool: Arc<RwLock<Pool<ConnectionManager<C>>>>
) -> Self
Create a new DieselAdminServiceStore with write exclusivity enabled.
Write exclusivity is enforced by providing a connection pool that is wrapped in a
RwLock. This ensures that there may be only one writer, but many readers.
Arguments
connection_pool: read-write lock-guarded connection pool for the database