Struct splinter::biome::DieselOAuthUserSessionStore
source · [−]pub struct DieselOAuthUserSessionStore<C: Connection + 'static> { /* private fields */ }Expand description
A database-backed OAuthUserSessionStore, powered by diesel.
Implementations
sourceimpl<C: Connection + 'static> DieselOAuthUserSessionStore<C>
impl<C: Connection + 'static> DieselOAuthUserSessionStore<C>
pub fn new(connection_pool: Pool<ConnectionManager<C>>) -> Self
sourcepub fn new_with_write_exclusivity(
connection_pool: Arc<RwLock<Pool<ConnectionManager<C>>>>
) -> Self
pub fn new_with_write_exclusivity(
connection_pool: Arc<RwLock<Pool<ConnectionManager<C>>>>
) -> Self
Create a new DieselOAuthUserSessionStore with write exclusivity enabled.
Write exclusivity is enforced by providing a connection pool that is wrapped in a
RwLock. This ensures that there may be only one writer, but many readers.
Arguments
connection_pool: read-write lock-guarded connection pool for the database