Struct splinter::rest_api::auth::authorization::allow_keys::AllowKeysAuthorizationHandler
source · [−]pub struct AllowKeysAuthorizationHandler { /* private fields */ }Expand description
A file-backed authorization handler that permits admin keys
The authorization handler only accepts Identity::Key identities; if a different type of
identity is provided, the handler will return AuthorizationHandlerResult::Continue. If a key
is provided, the handler will check if the key is present in the backing file. If the key is in
the backing file, the handler will return AuthorizationHandlerResult::Allow; if not, it will
return AuthorizationHandlerResult::Continue. The permission_id argument for
AuthorizationHandler::has_permission is ignored because this authorization handler provides
admin privileges (all permissions).
The authorization handler’s backing file must be a list of keys separated by newlines.
The list of keys in the file are cached in-memory by the authorization handler; this means that
the handler will not have to read from the file every time permissions are checked. Instead,
each time the handler checks for permissions, it will check the backing file for any changes
since the last read, refreshing the internal cache if necessary. If the backing file does not
exist, is removed, or becomes unavailable, the authorization handler will treat the list of keys
as empty (all permission checks will receive a AuthorizationHandlerResult::Continue result).
Implementations