Struct splinter::sets::mem::DurableBTreeSet [−][src]
An in-memory, DurableOrderedSet, backed by a BTreeSet.
This set is bounded, where in it will drop the first item in the set, based on the natural order of the items stored.
Implementations
pub fn new_boxed<Index>() -> Box<dyn DurableOrderedSet<V, Index>> where
Index: Ord + Send + Clone,
V: Send + Ord + Borrow<Index> + Clone + 'static, pub fn new_boxed_with_bound<Index>(
bound: NonZeroUsize
) -> Box<dyn DurableOrderedSet<V, Index>> where
Index: Ord + Send + Clone,
V: Send + Ord + Borrow<Index> + Clone + 'static, Trait Implementations
Returns the “default value” for a type. Read more
impl<V, Index> DurableOrderedSet<V, Index> for DurableBTreeSet<V> where
Index: Ord + Send,
V: Send + Ord + Borrow<Index> + Clone + 'static,
impl<V, Index> DurableOrderedSet<V, Index> for DurableBTreeSet<V> where
Index: Ord + Send,
V: Send + Ord + Borrow<Index> + Clone + 'static, fn range_iter<'a>(
&'a self,
range: DurableRange<&Index>
) -> Result<Box<dyn Iterator<Item = Self::Item> + 'a>, DurableSetError>
fn range_iter<'a>(
&'a self,
range: DurableRange<&Index>
) -> Result<Box<dyn Iterator<Item = Self::Item> + 'a>, DurableSetError>Returns an iterator over a range
Get a value based on the index.
Check for the existence of a value based on the index.
Returns the first item in the set, based on the natural Item order.
Returns the last item in the set, based on the natural Item order.
Clones this instance into a boxed durable ordered set.
Remove an item to the set.
type Item = VReturns an iterator over the contents of the set.
Get a value based on the query item.
Returns the count of the values in the set.