pub struct InfluxRecorder { /* private fields */ }Expand description
Enables using the metrics macros and sending the metrics data to a running Influx database
Implementations
sourceimpl InfluxRecorder
impl InfluxRecorder
sourcepub fn init(
db_url: &str,
db_name: &str,
username: &str,
password: &str
) -> Result<(), InternalError>
pub fn init(
db_url: &str,
db_name: &str,
username: &str,
password: &str
) -> Result<(), InternalError>
Initialize metric collection by creating the InfluxRecorder that will connect to the InfluxDB instance. The record is then added to the metrics library as the recorder which enables sending the metrics data to the database.
Arguments
db_url- The URL to connect the InfluxDB database for metrics collectiondb_name- The name of the InfluxDB database for metrics Collection.username- The username used for authorization with the InfluxDB.password- The password used for authorization with the InfluxDB.