pub struct MultiTransport { /* private fields */ }Expand description
A MultiTransport holds a collection of transports, referenced by protocol.
Endpoints and bind strings are specified using standard url-style strings. For example,
connecting over TLS would be handled with the connect string "tcps://<some-address>:<port>"
Endpoints and bind strings provided without a protocol will use the provided default transport protocol type.
Implementations