pub struct WsTransport { /* private fields */ }Expand description
A WebSocket-based Transport.
Supports endpoints of the format ws://ip_or_host:port.
Examples
To connect to the a remote endpoint, send a message, and receive a reply message:
use splinter::transport::Transport as _;
use splinter::transport::ws::WsTransport;
fn main() -> Result<(), Box<dyn std::error::Error>> {
let mut transport = WsTransport::new(None)?;
// Connect to a remote endpoint starting wtih `ws://`.
let mut connection = transport.connect("ws://127.0.0.1:5555")?;
// Send some bytes
connection.send(b"hello world")?;
// Receive a response
let msg = connection.recv()?;
// Disconnect
connection.disconnect()?;
Ok(())
}To accept a connection, receive, and send a reply:
use splinter::transport::Transport as _;
use splinter::transport::ws::WsTransport;
fn main() -> Result<(), Box<dyn std::error::Error>> {
let mut transport = WsTransport::new(None)?;
// Create a listener, which will bind to the port
let mut listener = transport.listen("ws://127.0.0.1:5555")?;
// When the other side connects, accept will return a `Connection`
let mut connection = listener.accept()?;
// Receive a message
let msg = connection.recv()?;
// Send a response
connection.send(b"hello world")?;
// Disconnect
connection.disconnect()?;
Ok(())
}Implementations